@@ -1,18 +1,19 @@
 """Console script for covid19_outbreak_simulator."""
 import argparse
+import cProfile
 import multiprocessing
-import sys
-from io import StringIO
 import os
-from datetime import datetime
 import subprocess
+import sys
+from datetime import datetime
+from io import StringIO
 
 import numpy as np
 from tqdm import tqdm
 
 from .model import Params, summarize_model
-from .simulator import Simulator, load_plugins
 from .report import summarize_simulations
+from .simulator import Simulator, load_plugins
 
 
 def parse_args(args=None):
@@ -31,14 +32,13 @@ def parse_args(args=None):
         '--track-events',
         nargs='+',
         help='''List events to track, default to track all events. Event START and ERROR
-        will always be tracked.'''
-    )
+        will always be tracked.''')
     parser.add_argument(
         '--vicinity',
         nargs='*',
         help='''Number of "neighbors" from group "B" for individuals in
-        aubpopulation "A", specified as "A-B=n". For example, "A-A=0" avoids infection
-        within group "A", "A-A=10 A-B=5" will make infections twiece as likely
+        subpopulation "A", specified as "A-B=n". For example, "A-A=0" avoids infection
+        within group "A", "A-A=10 A-B=5" will make infections twice as likely
         to happen within group A then to group B, regardless of size of
         groups A and B. As specifial cases, 'A=10` etc refers to cases when
         infection happens from outside of the simulated population (community
@@ -79,8 +79,7 @@ def parse_args(args=None):
             for increasing and a stage for decreasing infectivity. The proportion of stages
             and time after incubation period are controlled by a lognormal distribution.
             Parameters to this model could be specified but not recommended.
-        '''
-    )
+        ''')
     parser.add_argument(
         '--asymptomatic-transmissibility-model',
         nargs='+',
@@ -91,17 +90,16 @@ def parse_args(args=None):
             infectivity. The proportion of stages and the overall duration are controlled
             by a lognormal distribution. Parameters to this model could be specified but
             not recommended.
-        '''
-    )
+        ''')
 
     parser.add_argument(
         '--incubation-period',
         nargs='+',
-        help='''Incubation period period, should be specified as "lognormal" followed by two
-            numbers as mean and sigma, or "normal" followed by mean and sd. Multipliers are
+        help='''Incubation period period, should be specified as a number for the mean
+            incubation period, which will be fitted to a lognormal distribution, or
+            "lognormal" followed by two numbers as mean and sigma, or "normal" followed by mean and sd. Multipliers are
             allowed to specify incubation period for each group. Default to
-            "lognormal 1.621 0.418"'''
-    )
+            "lognormal 1.621 0.418"''')
     parser.add_argument(
         '--repeats',
         default=100,
@@ -120,11 +118,14 @@ def parse_args(args=None):
         nargs='*',
         help='''How to handle individuals who show symptom, which should be "keep" (stay in
             population), "remove" (remove from population), "replace" (reset its infection status
-            so that the individual is susceptible again), and "quarantine" (put aside until
-            it recovers). all options can be followed by a "proportion", and quarantine can
-            be specified as "quarantine_7" etc to specify duration of quarantine. Default to
-            "remove", meaning all symptomatic cases will be removed from population.'''
-    )
+            so that the individual is susceptible again), "quarantine" (put aside until
+            it recovers). "reintegrate" (remove from quarantine, which is counterintuitive but
+            can be used for selecting uninfected indivudal through quarantine). All options can
+            be followed by a "proportion" in the format of "remove?proportion=0.7", and quarantine can be
+            specified as "quarantine?duration=7" etc to specify duration of quarantine. If multiple
+            subpopulation will have different ways to handle symptomatic cases, they should be specified
+            as multipliers (e.g. A=remove B=quarantine). Default to  "remove", meaning all symptomatic cases will be
+            removed from population.''')
     parser.add_argument(
         '--infectors',
         nargs='*',
@@ -142,7 +143,7 @@ def parse_args(args=None):
         '--prop-asym-carriers',
         nargs='*',
         help='''Proportion of asymptomatic cases. You can specify a fix number, or two
-        numbers as the lower and higher CI (95%%) of the proportion. Default to 0.10 to 0.40.
+        numbers as the lower and higher CI (95%%) of the proportion. Default to 0.40.
         Multipliers can be specified to set proportion of asymptomatic carriers
         for particular groups.''')
     parser.add_argument(
@@ -177,32 +178,37 @@ def parse_args(args=None):
         '-v',
         '--version',
         action='store_true',
-        help='Print version information'
+        help='Print version information')
+    parser.add_argument(
+        '--verbosity',
+        default=1,
+        type=int,
+        choices=[0, 1, 2],
+        help='''Set verbosity level of the simulator, default to 1 (general), can be
+            set to 0 (suppress warning and commands for START etc) only.'''
     )
     parser.add_argument(
         '--summarize-model',
         action='store_true',
         help='''If specified, output key statistics calculated such as mean serial interval directly
             from model parameters. No simulation will actually be executed if this parameter is
-            specified.'''
-    )
+            specified. It will also trigger the "summarize-model" mode for plugins if the plugin
+            supports this feature.''')
     parser.add_argument(
         '--summary-report',
         help='''Generate a summary report and write to the specified file,
-          which can be "-" for standard output.'''
-    )
+          which can be "-" for standard output.''')
     parser.add_argument(
-        '--sensitivity',
-        nargs='+',
-        type=float,
-        default=[1.0],
-        help=argparse.SUPPRESS
+        '--profile',
+        help='''Profile worker and write profile result to specified file'''
     )
     return parser.parse_args(args)
 
+
 class FilteredStringIO(StringIO):
+
     def __init__(self, track_events=None):
-        super(FilteredStringIO, self).__init__()
+        super().__init__()
         self._track_events = track_events
         if self._track_events is not None:
             self._track_events = set(self._track_events)
@@ -210,10 +216,10 @@ class FilteredStringIO(StringIO):
                 if evt not in self._track_events:
                     self._track_events.add(evt)
 
-
     def write(self, text):
         if not self._track_events or text.split('\t')[1] in self._track_events:
-            super(FilteredStringIO, self).write(text)
+            super().write(text)
+
 
 class Worker(multiprocessing.Process):
 
@@ -228,13 +234,17 @@ class Worker(multiprocessing.Process):
     def run(self):
         # set random seed to a random number
         np.random.seed()
+        if self.simu_args.profile:
+            pr = cProfile.Profile()
+            pr.enable()
 
         while True:
             id = self.task_queue.get()
             if id is None:
                 self.task_queue.task_done()
                 break
-            with FilteredStringIO(track_events = self.simu_args.track_events) as logger:
+            with FilteredStringIO(
+                    track_events=self.simu_args.track_events) as logger:
                 simu = Simulator(
                     params=self.params,
                     logger=logger,
@@ -253,6 +263,9 @@ class Worker(multiprocessing.Process):
                 self.task_queue.task_done()
                 self.result_queue.put(logger.getvalue())
 
+        if self.simu_args.profile:
+            pr.disable()
+            pr.dump_stats(self.simu_args.profile)
 
 def main(argv=None):
     """Console script for covid19_outbreak_simulator."""
@@ -261,12 +274,8 @@ def main(argv=None):
         from . import __version__
         print(f'COVID10 Outbreak Simulator version {__version__}')
         sys.exit(0)
-    if args.summarize_model:
-        summarize_model(Params(args), args)
-        sys.exit(0)
 
-    tasks = multiprocessing.JoinableQueue()
-    results = multiprocessing.Queue()
+    plugins = []
     if args.plugin:
         if args.plugin[0] == '-h':
             # list all plugins
@@ -275,10 +284,13 @@ def main(argv=None):
             parser = bp.get_parser()
             parser.parse_args(['-h'])
         # load the plugins just to check if the parameters are ok
-        load_plugins(args.plugin)
+        plugins = load_plugins(args.plugin)
 
     if not args.jobs:
-        args.jobs = multiprocessing.cpu_count()
+        args.jobs = 1 if args.profile else multiprocessing.cpu_count()
+
+    if args.profile and args.jobs > 1:
+        raise ValueError(f'Please use a single worker (-j 1) when profiling is enabled with --profile.')
 
     if args.stop_if is not None:
         if args.stop_if[0].startswith('t>'):
@@ -288,12 +300,20 @@ def main(argv=None):
             except Exception as e:
                 raise ValueError(
                     f'Invalid value for option --stop-if "{args.stop_if[0]}": {e}'
-                )
+                ) from e
         else:
             raise ValueError(
-                f'Option --stop-if currently only supports t>TIME to stop after certain time point.'
+                'Option --stop-if currently only supports t>TIME to stop after certain time point.'
             )
 
+    if args.summarize_model:
+        summarize_model(args)
+        for plugin, plugin_args in plugins:
+            plugin.summarize_model(args, plugin_args)
+        sys.exit(0)
+
+    tasks = multiprocessing.JoinableQueue()
+    results = multiprocessing.Queue()
     completed_ids = 0
 
     # check the last line
@@ -312,31 +332,45 @@ def main(argv=None):
         else:
             fields = last_line.split('\t')
             if len(fields) != 5:
-                raise ValueError(f'Existing file is corrupeted. Please fix before continue: "{last_line.strip()}" does not have five fields.')
+                raise ValueError(
+                    f'Existing file is corrupeted. Please fix before continue: "{last_line.strip()}" does not have five fields.'
+                )
             if fields[2] != 'END':
-                raise ValueError(f'Last record of replicate ends with line "{last_line.strip()}" is not an "END" event. Please fix before continue.')
+                raise ValueError(
+                    f'Last record of replicate ends with line "{last_line.strip()}" is not an "END" event. Please fix before continue.'
+                )
             completed_ids = int(fields[0])
 
     if args.resume:
         if completed_ids == args.repeats:
-            print(f'All simulations have been performed. Remove {args.logfile} if you would like to rerun.')
+            print(
+                f'All simulations have been performed. Remove {args.logfile} if you would like to rerun.'
+            )
             return 0
         if completed_ids > args.repeats:
-            print(f'More than requested {args.repeats} replicates exists in {args.logfile}. Remove the logfile if you would like to rerun.')
+            print(
+                f'More than requested {args.repeats} replicates exists in {args.logfile}. Remove the logfile if you would like to rerun.'
+            )
             return 0
         if completed_ids != 0:
-            print(f'Resuming from {completed_ids} completed records in {args.logfile}')
+            print(
+                f'Resuming from {completed_ids} completed records in {args.logfile}'
+            )
     elif completed_ids != 0:
-        print(f'Overwriting {completed_ids} completed records in {args.logfile}')
+        print(
+            f'Overwriting {completed_ids} completed records in {args.logfile}')
         completed_ids = 0
 
     if os.path.isfile(args.logfile + '.lock'):
-        raise RuntimeError(f'The output logfile {args.logfile} is locked. Please remove {args.logfile}.lock manually if you are certain that no other process is writing to the logfile')
+        raise RuntimeError(
+            f'The output logfile {args.logfile} is locked. Please remove {args.logfile}.lock manually if you are certain that no other process is writing to the logfile'
+        )
 
     submitted = 0
     try:
         with open(args.logfile + '.lock', 'w') as lock:
-            lock.write(f'START: {datetime.now().strftime("%m/%d/%Y-%H:%M:%S")}\n')
+            lock.write(
+                f'START: {datetime.now().strftime("%m/%d/%Y-%H:%M:%S")}\n')
             lock.write(f'CMD: {subprocess.list2cmdline(sys.argv)}')
 
         workers = [
@@ -350,25 +384,30 @@ def main(argv=None):
             if completed_ids == 0:
                 logger.write('id\ttime\tevent\ttarget\tparams\n')
             for i in range(args.repeats):
-                if i+1 > completed_ids:
+                if i + 1 > completed_ids:
                     submitted += 1
                     tasks.put(i + 1)
             for i in range(args.jobs):
                 tasks.put(None)
             #
-            for i in tqdm(range(completed_ids, args.repeats),
-                total=args.repeats, initial=completed_ids):
+            for i in tqdm(
+                    range(completed_ids, args.repeats),
+                    total=args.repeats,
+                    initial=completed_ids):
                 result = results.get()
                 lines = result.splitlines()
                 first_fields = lines[0].split('\t')
                 if len(first_fields) != 4 or first_fields[1] != 'START':
-                    raise ValueError(f'Wrong starting record reported: {lines[0]}')
+                    raise ValueError(
+                        f'Wrong starting record reported: {lines[0]}')
                 last_fields = lines[-1].split('\t')
-                if len(last_fields) != 4 or last_fields[1] not in ('END', 'ERROR'):
-                    raise ValueError(f'Wrong last record reported: {lines[-1]} ')
+                if len(last_fields) != 4 or last_fields[1] not in ('END',
+                                                                   'ERROR'):
+                    raise ValueError(
+                        f'Wrong last record reported: {lines[-1]} ')
                 logger.write(''.join(f'{i+1}\t{line}\n' for line in lines))
                 if last_fields[1] == 'ERROR':
-                    break
+                    raise RuntimeError(last_fields[2])
                 if i % 1000 == 999:
                     logger.flush()
     finally:
