@@ -1,15 +1,18 @@
 import os
 import re
+from fnmatch import fnmatch
 
 import numpy as np
 import pandas as pd
+import yaml
 from scipy.optimize import bisect
 from scipy.stats import norm
+from .event import EventType
 from covid19_outbreak_simulator.utils import as_float, as_int
-from fnmatch import fnmatch
-import yaml
+
 
 class Params:
+
     def __init__(self, args=None):
         # args should be args returned from argparser
         self.params = {
@@ -26,17 +29,22 @@ class Params:
         self.set_params(args)
 
     def __str__(self):
+
         def float_representer(dumper, value):
             text = '{0:.4f}'.format(value)
             return dumper.represent_scalar(u'tag:yaml.org,2002:float', text)
+
         yaml.add_representer(float, float_representer)
 
-        val = {x:list(y) if isinstance(y, set) else y for x,y in self.__dict__.items() if x != 'params'}
+        val = {
+            x: list(y) if isinstance(y, set) else y
+            for x, y in self.__dict__.items()
+            if x != 'params'
+        }
         if 'groups' in val and len(val['groups']) == 1:
             val['groups'] = {'Unnamed': list(val['groups'].values())[0]}
         return yaml.dump(val, sort_keys=True, indent=4)
 
-
     def set(self, param, prop, value):
         if param not in self.params:
             raise ValueError(f"Unrecgonzied parameter {param}")
@@ -51,15 +59,20 @@ class Params:
                     f'Group {group} does not exist. Available groups are: {", ".join(self.groups.keys())}'
                 )
             if value < 0:
-                raise ValueError(f"Multiplier should be positive {value} specified")
+                raise ValueError(
+                    f"Multiplier should be positive {value} specified")
             setattr(self, f"{param}_{prop}", value)
         elif re.match("quantile_(.*)", prop):
             lq = float(re.match("quantile_(.*)", prop)[1]) / 100
             loc = getattr(self, f"{param}_loc")
-            sd = bisect(
-                lambda x: norm.cdf(value, loc=loc, scale=x) - lq, a=0.00001, b=25
-            )
-            setattr(self, f"{param}_scale", sd)
+            if loc == value:
+                setattr(self, f"{param}_scale", 0)
+            else:
+                sd = bisect(
+                    lambda x: norm.cdf(value, loc=loc, scale=x) - lq,
+                    a=0.00001,
+                    b=25)
+                setattr(self, f"{param}_scale", sd)
         else:
             raise ValueError(f"Unrecognized property {prop}")
 
@@ -91,7 +104,8 @@ class Params:
                 size = ps
             size = as_int(size)
             if name == 'all':
-                raise ValueError('Group name "all" is reserved for the entire population.')
+                raise ValueError(
+                    'Group name "all" is reserved for the entire population.')
             if name in self.groups:
                 raise ValueError(f'Group "{name}" has been specified before')
             self.groups[name] = size
@@ -104,17 +118,18 @@ class Params:
 
     def _set_multiplier(self, multiplier, param_name):
         name, value = multiplier.split("=", 1)
-        value = as_float(value, "Multiplier should have format name=float_value")
+        value = as_float(value,
+                         "Multiplier should have format name=float_value")
         if name == 'all':
-            self.set(param_name, f"multiplier_", value)
+            self.set(param_name, "multiplier_", value)
         else:
-            names = [x for x in self.groups.keys() if fnmatch(x, name)]
+            names = [x for x, y in self.groups.items() if fnmatch(x, name)]
             if not names:
-                raise ValueError(f"Invalid group name {name} in multiplier {multiplier}")
+                raise ValueError(
+                    f"Invalid group name {name} in multiplier {multiplier}")
             for name in names:
                 self.set(param_name, f"multiplier_{name}", value)
 
-
     def set_symptomatic_r0(self, val):
         if not val:
             return
@@ -143,7 +158,8 @@ class Params:
             self.set("symptomatic_r0", "quantile_2.5", p0)
 
         elif len(pars) > 2:
-            raise ValueError(f"The symptomatic_r0 should be one or two float number.")
+            raise ValueError(
+                "The symptomatic_r0 should be one or two float number.")
         #
         for multiplier in [x for x in val if "=" in x]:
             self._set_multiplier(multiplier, "symptomatic_r0")
@@ -179,7 +195,8 @@ class Params:
                 p0,
             )
         elif len(pars) > 2:
-            raise ValueError(f"The asymptomatic_r0 should be one or two float number.")
+            raise ValueError(
+                "The asymptomatic_r0 should be one or two float number.")
         #
         for multiplier in [x for x in val if "=" in x]:
             self._set_multiplier(multiplier, "asymptomatic_r0")
@@ -190,30 +207,38 @@ class Params:
 
         pars = [x for x in val if x in ("normal", "lognormal") or "=" not in x]
         if pars:
-            if len(pars) < 3:
-                raise ValueError(
-                    f"Parameter incubation period requires aat least three values: {len(val)} provided"
+            if pars[0] in ("normal", "lognormal"):
+                self.set(
+                    "incubation_period",
+                    "mean" if pars[0] == "lognormal" else "loc",
+                    as_float(
+                        pars[1],
+                        "Second parameter of incubation_period should be a float number",
+                    ),
                 )
-            if pars[0] not in ("normal", "lognormal"):
-                raise ValueError(
-                    f"Only normal or lognormal distribution for incubation period is supported. {pars[0]} provided"
+                self.set(
+                    "incubation_period",
+                    "sigma" if pars[0] == "lognormal" else "scale",
+                    as_float(
+                        pars[2],
+                        "Third parameter of lognormal incubation_period should be a float number",
+                    ),
                 )
-            self.set(
-                "incubation_period",
-                "mean" if pars[0] == "lognormal" else "loc",
-                as_float(
-                    pars[1],
-                    "Second parameter of incubation_period should be a float number",
-                ),
-            )
-            self.set(
-                "incubation_period",
-                "sigma" if pars[0] == "lognormal" else "scale",
-                as_float(
-                    pars[2],
-                    "Third parameter of lognormal incubation_period should be a float number",
-                ),
-            )
+            elif len(pars) == 1:
+                self.set(
+                    "incubation_period",
+                    "mean",
+                    np.log(
+                        as_float(
+                            pars[0],
+                            "First parameter of incubation_period should be a float number if not model name",
+                        )) - 1 / 2 * 0.418**2,
+                )
+                self.set("incubation_period", "sigma", 0.418)
+            else:
+                raise ValueError(
+                    'Unacceptable specification of incubation period')
+
         # multipliers
         for multiplier in [x for x in val if "=" in x]:
             self._set_multiplier(multiplier, "incubation_period")
@@ -236,8 +261,10 @@ class Params:
     def set_symptomatic_transmissibility_model(self, val):
         if not val or val[0] not in ('normal', 'piecewise'):
             raise ValueError("Only a normal and a piecewise model is supported")
-        elif val[0] == "normal":
+
+        if val[0] == "normal":
             self.symptomatic_transmissibility_model = dict(name="normal")
+
         elif len(val) == 1:
             self.symptomatic_transmissibility_model = dict(
                 name=val[0],
@@ -247,6 +274,7 @@ class Params:
                 duration_mean=0.8653416550012768,
                 duration_sigma=1.0332881142805803,
             )
+
         elif len(val) != 6:
             raise ValueError(
                 f"""Parameter --symptomatic-transmissibility-model should be
@@ -313,9 +341,11 @@ class Params:
         elif len(base) > 1:
             raise ValueError("Susceptibility should be a single number.")
         else:
-            base_val = as_float(base[0], "Susceptibility should be a float number")
+            base_val = as_float(base[0],
+                                "Susceptibility should be a float number")
             if base_val > 1 or base_val < 0:
-                raise ValueError("suscepbility should be betwee 0 and 1: {base_val}")
+                raise ValueError(
+                    "suscepbility should be betwee 0 and 1: {base_val}")
             self.set("susceptibility", "mean", base_val)
 
         for multiplier in [x for x in val if isinstance(x, str) and "=" in x]:
@@ -326,37 +356,37 @@ class Params:
             return
         try:
             pars = [float(x) for x in val if "=" not in x]
-        except Exception:
+        except Exception as e:
             raise ValueError(
                 f'Paramter prop-asym-carriers expect one or two float value or multipliers: {" ".join(val)} provided'
-            )
+            ) from e
         if len(pars) == 1:
             self.set("prop_asym_carriers", "loc", as_float(pars[0]))
             self.set("prop_asym_carriers", "scale", 0)
         elif len(pars) == 2:
             if pars[0] > pars[1]:
                 raise ValueError(
-                    f"Proportions for parameter prop-asym-carriers should be incremental."
+                    "Proportions for parameter prop-asym-carriers should be incremental."
                 )
             self.set("prop_asym_carriers", "loc", (pars[0] + pars[1]) / 2)
             self.set("prop_asym_carriers", "quantile_2.5", pars[0])
         elif len(pars) > 2:
             raise ValueError(
-                f"Parameter prop-asym-carriers accepts one or two numbers."
-            )
+                "Parameter prop-asym-carriers accepts one or two numbers.")
         #
         for multiplier in [x for x in val if "=" in x]:
             self._set_multiplier(multiplier, "prop_asym_carriers")
 
     def set_params(self, args):
         # set some default values first
-        self.set("simulation_interval", "self", args.interval if args else 1 / 24)
-        self.set("prop_asym_carriers", "loc", 0.25)
-        self.set("prop_asym_carriers", "quantile_2.5", 0.1)
+        self.set("simulation_interval", "self",
+                 args.interval if args else 1 / 24)
+        self.set("prop_asym_carriers", "loc", 0.4)
+        self.set("prop_asym_carriers", "scale", 0)
         self.set("symptomatic_r0", "loc", (1.4 + 2.8) / 2)
         self.set("symptomatic_r0", "quantile_2.5", 1.4)
-        self.set("asymptomatic_r0", "loc", (0.28 + 0.56) / 2)
-        self.set("asymptomatic_r0", "quantile_2.5", 0.28)
+        self.set("asymptomatic_r0", "loc", (1.4 + 2.8) * 0.75 / 2)
+        self.set("asymptomatic_r0", "quantile_2.5", 1.4 * 0.75)
         self.set("incubation_period", "mean", 1.621)
         self.set("incubation_period", "sigma", 0.418)
         self.symptomatic_transmissibility_model = {"name": "normal"}
@@ -372,11 +402,9 @@ class Params:
         self.set_asymptomatic_r0(args.asymptomatic_r0)
         self.set_incubation_period(args.incubation_period)
         self.set_symptomatic_transmissibility_model(
-            args.symptomatic_transmissibility_model
-        )
+            args.symptomatic_transmissibility_model)
         self.set_asymptomatic_transmissibility_model(
-            args.asymptomatic_transmissibility_model
-        )
+            args.asymptomatic_transmissibility_model)
         self.set_susceptibility(args.susceptibility)
         self.set_prop_asym_carriers(args.prop_asym_carriers)
 
@@ -397,8 +425,8 @@ class Model(object):
         )
         return min(
             max(
-                self.params.prop_asym_carriers
-                * getattr(self.params, f"prop_asym_carriers_multiplier_{group}", 1.0),
+                self.params.prop_asym_carriers * getattr(
+                    self.params, f"prop_asym_carriers_multiplier_{group}", 1.0),
                 0,
             ),
             1,
@@ -415,16 +443,18 @@ class Model(object):
             if self.params.symptomatic_r0_scale == 0.0:
                 return self.params.symptomatic_r0_loc
             else:
-                return max(0, np.random.normal(
-                    self.params.symptomatic_r0_loc, self.params.symptomatic_r0_scale
-                ))
+                return max(
+                    0,
+                    np.random.normal(self.params.symptomatic_r0_loc,
+                                     self.params.symptomatic_r0_scale))
         else:
             if self.params.asymptomatic_r0_scale == 0.0:
                 return self.params.asymptomatic_r0_loc
             else:
-                return max(0, np.random.normal(
-                    self.params.asymptomatic_r0_loc, self.params.asymptomatic_r0_scale
-                ))
+                return max(
+                    0,
+                    np.random.normal(self.params.asymptomatic_r0_loc,
+                                     self.params.asymptomatic_r0_scale))
 
     def draw_random_incubation_period(self, group=""):
         """
@@ -444,59 +474,60 @@ class Model(object):
                 mean=self.params.incubation_period_mean,
                 sigma=self.params.incubation_period_sigma,
             )
-        return ip * getattr(self.params, f"incubation_period_multiplier_{group}", 1.0)
+        return ip * getattr(self.params,
+                            f"incubation_period_multiplier_{group}", 1.0)
 
     def draw_infection_params(self, symptomatic):
         if symptomatic:
             # duration of infection is 8 days after incubation
-            if self.params.symptomatic_transmissibility_model["name"] == "normal":
+            if self.params.symptomatic_transmissibility_model[
+                    "name"] == "normal":
                 return [8]
             # duration of infection is shift + lognormal distribution
             else:
                 return [
-                    self.params.symptomatic_transmissibility_model["duration_shift"]
-                    + np.random.lognormal(
-                        self.params.symptomatic_transmissibility_model["duration_mean"],
-                        self.params.symptomatic_transmissibility_model[
-                            "duration_sigma"
-                        ],
+                    self.params
+                    .symptomatic_transmissibility_model["duration_shift"] +
+                    np.random.lognormal(
+                        self.params
+                        .symptomatic_transmissibility_model["duration_mean"],
+                        self.params
+                        .symptomatic_transmissibility_model["duration_sigma"],
                     )
                 ]
         else:
             # 12 day overall (with normal at 4.8)
-            if self.params.asymptomatic_transmissibility_model["name"] == "normal":
+            if self.params.asymptomatic_transmissibility_model[
+                    "name"] == "normal":
                 return [12]
             # asymptomatic
             else:
                 return [
-                    self.params.asymptomatic_transmissibility_model["duration_shift"]
-                    + np.random.lognormal(
-                        self.params.asymptomatic_transmissibility_model[
-                            "duration_mean"
-                        ],
-                        self.params.asymptomatic_transmissibility_model[
-                            "duration_sigma"
-                        ],
+                    self.params
+                    .asymptomatic_transmissibility_model["duration_shift"] +
+                    np.random.lognormal(
+                        self.params
+                        .asymptomatic_transmissibility_model["duration_mean"],
+                        self.params
+                        .asymptomatic_transmissibility_model["duration_sigma"],
                     )
                 ]
 
     def get_symptomatic_transmission_probability(self, incu, R0, params):
         if self.params.symptomatic_transmissibility_model["name"] == "normal":
             return self.get_normal_symptomatic_transmission_probability(
-                incu, R0, params
-            )
+                incu, R0, params)
         else:
             return self.get_piecewise_symptomatic_transmission_probability(
-                incu, R0, params
-            )
+                incu, R0, params)
 
     def get_asymptomatic_transmission_probability(self, R0, params):
         if self.params.asymptomatic_transmissibility_model["name"] == "normal":
-            return self.get_normal_asymptomatic_transmissibility_probability(R0, params)
+            return self.get_normal_asymptomatic_transmissibility_probability(
+                R0, params)
         else:
             return self.get_piecewise_asymptomatic_transmissibility_probability(
-                R0, params
-            )
+                R0, params)
 
     def get_normal_symptomatic_transmission_probability(self, incu, R0, params):
         """Transmission probability.
@@ -550,11 +581,12 @@ class Model(object):
             )
             idx = int(incu / self.params.simulation_interval)
             y = np.concatenate(
-                [dist_left.pdf(x[:idx]) * scale, dist_right.pdf(x[idx:])]
-            )
+                [dist_left.pdf(x[:idx]) * scale,
+                 dist_right.pdf(x[idx:])])
         return x, y / sum(y) * R0
 
-    def get_piecewise_symptomatic_transmission_probability(self, incu, R0, params):
+    def get_piecewise_symptomatic_transmission_probability(
+            self, incu, R0, params):
         """Transmission probability.
         incu
             incubation period in days (can be float)
@@ -567,20 +599,6 @@ class Model(object):
 
         returns
 
-        x
-            time point
-        y
-            probability of transmission for each time point
-        """
-        """Asymptomatic Transmission probability.
-        R0
-            reproductive number, which is the expected number of infectees
-
-        interval
-            interval of simulation, default to 1/24, which is by hours
-
-        returns
-
         x
             time point
         y
@@ -588,20 +606,21 @@ class Model(object):
         """
         duration = incu + params[0]
         #
-        x = np.linspace(0, duration, int(duration / self.params.simulation_interval))
+        x = np.linspace(0, duration,
+                        int(duration / self.params.simulation_interval))
         infect_time = (
-            incu
-            * self.params.symptomatic_transmissibility_model[
-                "noninfectivity_proportion"
-            ]
-        )
+            incu * self.params
+            .symptomatic_transmissibility_model["noninfectivity_proportion"])
         peak_time = (
-            incu * self.params.symptomatic_transmissibility_model["peak_proportion"]
-        )
+            incu *
+            self.params.symptomatic_transmissibility_model["peak_proportion"])
 
         y = np.piecewise(
             x,
-            [x < infect_time, (x >= infect_time) & (x < peak_time), x >= peak_time],
+            [
+                x < infect_time,
+                (x >= infect_time) & (x < peak_time), x >= peak_time
+            ],
             [
                 0,
                 lambda y: (y - infect_time) / (peak_time - infect_time),
@@ -627,11 +646,13 @@ class Model(object):
             probability of transmission for each time point
         """
         dist = norm(4.8, self.sd_5)
-        x = np.linspace(0, params[0], int(params[0] / self.params.simulation_interval))
+        x = np.linspace(0, params[0],
+                        int(params[0] / self.params.simulation_interval))
         y = dist.pdf(x)
         return x, y / sum(y) * R0
 
-    def get_piecewise_asymptomatic_transmissibility_probability(self, R0, params):
+    def get_piecewise_asymptomatic_transmissibility_probability(
+            self, R0, params):
         """Asymptomatic Transmission probability.
         R0
             reproductive number, which is the expected number of infectees
@@ -648,21 +669,21 @@ class Model(object):
         """
         duration = params[0]
         #
-        x = np.linspace(0, duration, int(duration / self.params.simulation_interval))
+        x = np.linspace(0, duration,
+                        int(duration / self.params.simulation_interval))
         infect_time = (
-            duration
-            * self.params.asymptomatic_transmissibility_model[
-                "noninfectivity_proportion"
-            ]
-        )
+            duration * self.params
+            .asymptomatic_transmissibility_model["noninfectivity_proportion"])
         peak_time = (
-            duration
-            * self.params.asymptomatic_transmissibility_model["peak_proportion"]
-        )
+            duration *
+            self.params.asymptomatic_transmissibility_model["peak_proportion"])
 
         y = np.piecewise(
             x,
-            [x < infect_time, (x >= infect_time) & (x < peak_time), x >= peak_time],
+            [
+                x < infect_time,
+                (x >= infect_time) & (x < peak_time), x >= peak_time
+            ],
             [
                 0,
                 lambda y: (y - infect_time) / (peak_time - infect_time),
@@ -675,6 +696,12 @@ class Model(object):
         return x, y
 
 
+def print_proportion(data, name):
+    series = pd.Series(data)
+    print('\n' + name + ':')
+    print(f'      proportion:  {series.mean():.4f}')
+
+
 def print_stats(data, name):
     series = pd.Series(data)
     print('\n' + name + ':')
@@ -683,16 +710,23 @@ def print_stats(data, name):
     for q in (0.025, 0.05, 0.5, 0.95, 0.975):
         print(f'  {q*100:4.1f}% quantile:  {series.quantile(q):.4f}')
 
+def print_cnt(data, name):
+    nums = sorted(list(set(data)))
+    print('\n' + name + ':')
+    for n in nums:
+        print(f'    {n}:\t{data.count(n)/len(data)*100:.1f}%')
+
 def sample_prop_asymp_carriers(model, N=1000):
     asym_carriers = []
-    for i in range(N):
+    for _ in range(N):
         model.draw_prop_asym_carriers()
         asym_carriers.append(model.draw_is_asymptomatic())
     return asym_carriers
 
 
-def summarize_model(params, args):
+def summarize_model(args):
     from .population import Individual
+    params = Params(args)
     print('Parameters (in YAML format)\n')
     print(params)
     print()
@@ -700,32 +734,36 @@ def summarize_model(params, args):
     print('Properties:')
     N = 5000
     model = Model(params)
-    print_stats(sample_prop_asymp_carriers(model, N),
+    print_proportion(
+        sample_prop_asymp_carriers(model, N),
         'Proportion of asymptomatic carriers')
 
     #
     model.params.set('prop_asym_carriers', 'loc', 0)
     model.params.set('prop_asym_carriers', 'scale', 0)
     print_stats([model.draw_random_incubation_period() for x in range(N)],
-        'Incubation period')
+                'Incubation period')
 
     print_stats([model.draw_random_r0(symptomatic=True) for x in range(N)],
-        'Production Number (Symptomatic)')
+                'Production Number (Symptomatic)')
     print_stats([model.draw_random_r0(symptomatic=False) for x in range(N)],
-        'Production Number (Asymptomatic)')
+                'Production Number (Asymptomatic)')
 
     model.params.set('prop_asym_carriers', 'loc', 0)
     model.params.set('prop_asym_carriers', 'scale', 0)
 
     cp = []
     du = []
+    cnt = []
     with open(os.devnull, 'w') as logger:
         logger.id = 1
         model.draw_prop_asym_carriers()
-        for i in range(N):
-            ind = Individual(id='0', susceptibility=1, model=model, logger=logger)
-            evts = ind.symptomatic_infect(time=0, by=None,
-                                        handle_symptomatic=['keep'])
+        for _ in range(N):
+            ind = Individual(
+                id='0', susceptibility=1, model=model, logger=logger)
+            evts = ind.symptomatic_infect(
+                time=0, by=None, handle_symptomatic=['keep'])
+            cnt.append(len([x for x in evts if x.action == EventType.INFECTION]))
             cp.append(ind.communicable_period())
             du.append(ind.total_duration())
 
@@ -734,20 +772,25 @@ def summarize_model(params, args):
 
     acp = []
     adu = []
+    acnt = []
     with open(os.devnull, 'w') as logger:
         logger.id = 1
         model.draw_prop_asym_carriers()
-        for i in range(N):
-            ind = Individual(id='0', susceptibility=1, model=model, logger=logger)
-            evts = ind.asymptomatic_infect(time=0, by=None,
-                                        handle_symptomatic=['keep'])
+        for _ in range(N):
+            ind = Individual(
+                id='0', susceptibility=1, model=model, logger=logger)
+            evts = ind.asymptomatic_infect(
+                time=0, by=None, handle_symptomatic=['keep'])
+            acnt.append(len([x for x in evts if x.action == EventType.INFECTION]))
             acp.append(ind.communicable_period())
             adu.append(ind.total_duration())
 
     print_stats(cp, 'Communicable Period (Symptomatic)')
     print_stats(du, 'Total Duration (Symptomatic)')
+    print_cnt(cnt, 'Number of infections (Symptomatic)')
     print_stats(acp, 'Communicable Period (Asymptomatic)')
     print_stats(adu, 'Total Duration (Asymptomatic)')
+    print_cnt(acnt, 'Number of infections (Asymptomatic)')
 
     model.params.set('prop_asym_carriers', 'loc', 0)
     model.params.set('prop_asym_carriers', 'scale', 0)
@@ -758,36 +801,16 @@ def summarize_model(params, args):
     with open(os.devnull, 'w') as logger:
         logger.id = 1
         model.draw_prop_asym_carriers()
-        for i in range(N):
-            ind = Individual(id='0', susceptibility=1, model=model, logger=logger)
-            evts = ind.symptomatic_infect(time=0, by=None,
-                                        handle_symptomatic=['keep'])
+        for _ in range(N):
+            ind = Individual(
+                id='0', susceptibility=1, model=model, logger=logger)
+            evts = ind.symptomatic_infect(
+                time=0, by=None, handle_symptomatic=['keep'])
             for evt in [x for x in evts if x.action.name == 'INFECTION']:
                 gt.append(evt.time)
-                si.append(evt.time + ind.model.draw_random_incubation_period() - ind.incubation_period)
+                si.append(evt.time + ind.model.draw_random_incubation_period() -
+                          ind.incubation_period)
                 break
 
     print_stats(si, 'Serial Interval')
     print_stats(gt, 'Generation Time')
-
-    # average test sensitivity
-    sensitivities = []
-    with open(os.devnull, 'w') as logger:
-        logger.id = 1
-
-        for i in range(10000):
-            model.draw_prop_asym_carriers()
-            ind = Individual(id='0', susceptibility=1, model=model, logger=logger)
-            ind.infect(0, by=None, leadtime=0)
-
-            for i in range(0, 15):
-
-                test_lod = args.sensitivity[1] if len(args.sensitivity) == 2 else 0
-
-                lod_sensitivity = ind.test_sensitivity(i, test_lod)
-                if lod_sensitivity == 0:
-                    continue
-                #
-                sensitivity = lod_sensitivity * args.sensitivity[0]
-                sensitivities.append(sensitivity)
-    print_stats(sensitivities, "Test sensitivity")
