@@ -1,11 +1,12 @@
 import copy
-import math
+import re
+from fnmatch import fnmatch
+
 import numpy as np
 from numpy.random import choice, rand
-from fnmatch import fnmatch
-from .utils import as_float
+
 from .event import Event, EventType
-import re
+from .utils import as_float, parse_handle_symptomatic_options
 
 
 class Individual(object):
@@ -15,9 +16,11 @@ class Individual(object):
         self.model = model
         self.susceptibility = 1.0 if susceptibility is None else min(
             1, susceptibility)
+
         self.logger = logger
 
         # these will be set to event happen time
+        self.immunity = None
         self.infectivity = None
         self.infected = False
         self.show_symptom = False
@@ -45,15 +48,12 @@ class Individual(object):
         self.quarantined = till
         return [
             Event(
-                till,
-                EventType.REINTEGRATION,
-                target=self.id,
-                logger=self.logger)
+                till, EventType.REINTEGRATION, target=self, logger=self.logger)
         ]
 
     def vaccinate(self, time, immunity, infectivity, **kwargs):
         self.vaccinated = time
-        self.susceptibility = 1 - immunity
+        self.immunity = immunity
         self.infectivity = infectivity
 
     def reintegrate(self):
@@ -65,9 +65,7 @@ class Individual(object):
         self.r0 = self.model.draw_random_r0(symptomatic=True, group=self.group)
 
         if self.infectivity is not None:
-            self.r0 *= self.infectivity
-            if self.r0 < 1:
-                return self.asymptomatic_infect(time, r0=self.r0, **kwargs)
+            self.r0 *= self.infectivity[0]
 
         self.r0_multiplier = getattr(self.model.params,
                                      f"symptomatic_r0_multiplier_{self.group}",
@@ -84,10 +82,10 @@ class Individual(object):
              self.incubation_period, self.r0 * self.r0_multiplier,
              self.infect_params)
 
-        by = kwargs.get("by", None)
+        by_ind = kwargs.get("by", None)
 
         if "leadtime" in kwargs and kwargs["leadtime"] is not None:
-            if by is not None:
+            if by_ind is not None:
                 raise ValueError(
                     "leadtime is only allowed during initialization of infection event (no by option.)"
                 )
@@ -104,12 +102,9 @@ class Individual(object):
             lead_time = 0
 
         self.infected = float(time - lead_time)
+        handle_symptomatic = parse_handle_symptomatic_options(
+            kwargs.get("handle_symptomatic", None), self.group)
 
-        if "handle_symptomatic" not in kwargs or kwargs[
-                "handle_symptomatic"] is None:
-            handle_symptomatic = ["remove", 1]
-        else:
-            handle_symptomatic = kwargs["handle_symptomatic"]
         # show symptom
         kept = True
         evts = []
@@ -122,28 +117,36 @@ class Individual(object):
                 Event(
                     symp_time,
                     EventType.SHOW_SYMPTOM,
-                    target=self.id,
+                    target=self,
                     logger=self.logger,
                 ))
         #
         if self.quarantined and self.quarantined > symp_time:
-            # show symptom during quarantine, ok
-            pass
-        elif handle_symptomatic[0] in ("remove", "keep"):
-            if len(handle_symptomatic) == 1:
-                proportion = 1
-            else:
-                proportion = as_float(
-                    handle_symptomatic[1],
-                    "Proportion in --handle-symptomatic remove/keep prop should be a float number",
-                )
-            if proportion > 1 or proportion < 0:
-                raise ValueError(
-                    f'Proportion in "--handle-symptomatic remove/keep prop" should be a float number between 0 and 1: {proportion} provided'
-                )
-            if (handle_symptomatic[0] == "keep" and
+            # show symptom during quarantine, check if need to reintegrate when show symptom
+            if handle_symptomatic['reaction'] == 'reintegrate':
+                proportion = handle_symptomatic.get('proportion', 1)
+
+                if proportion == 1 or np.random.uniform(0, 1,
+                                                        1)[0] <= proportion:
+                    if symp_time >= 0:
+                        evts.append(
+                            # scheduling reintegration
+                            Event(
+                                symp_time,
+                                EventType.INTEGRATION,
+                                target=self,
+                                logger=self.logger,
+                            ))
+                    else:
+                        # ignore
+                        self.logger.write(
+                            f'{time:.2f}\t{EventType.WARNING.name}\t{self.id}\tmsg="Individual not reintegrated before it show symptom before {time}"\n'
+                        )
+        elif handle_symptomatic['reaction'] in ("remove", "keep"):
+            proportion = handle_symptomatic.get('proportion', 1)
+            if (handle_symptomatic['reaction'] == "keep" and
                     np.random.uniform(0, 1, 1)[0] > proportion) or (
-                        handle_symptomatic[0] == "remove" and
+                        handle_symptomatic['reaction'] == "remove" and
                         (proportion == 1 or
                          np.random.uniform(0, 1, 1)[0] <= proportion)):
                 kept = False
@@ -153,7 +156,7 @@ class Individual(object):
                         Event(
                             symp_time,
                             EventType.REMOVAL,
-                            target=self.id,
+                            target=self,
                             logger=self.logger,
                         ))
                 else:
@@ -161,14 +164,14 @@ class Individual(object):
                     self.logger.write(
                         f'{time:.2f}\t{EventType.WARNING.name}\t{self.id}\tmsg="Individual not removed before it show symptom before {time}"\n'
                     )
-        elif handle_symptomatic[0] == "replace":
+        elif handle_symptomatic['reaction'] == "replace":
             if symp_time >= 0:
                 evts.append(
                     # scheduling REMOVAL
                     Event(
                         symp_time,
                         EventType.REPLACEMENT,
-                        target=self.id,
+                        target=self,
                         reason='symptom',
                         keep=['vaccinated'],
                         logger=self.logger,
@@ -178,25 +181,9 @@ class Individual(object):
                 self.logger.write(
                     f'{time:.2f}\t{EventType.WARNING.name}\t{self.id}\tmsg="Individual not replaced before it show symptom before {time}"\n'
                 )
-        elif handle_symptomatic[0].startswith("quarantine"):
-            if handle_symptomatic[0] == "quarantine":
-                quarantine_duration = 14
-            else:
-                quarantine_duration = as_float(
-                    handle_symptomatic[0].split("_", 1)[1],
-                    "quanrantine duration should be specified as quarantine_DURATION",
-                )
-            if len(handle_symptomatic) == 1:
-                proportion = 1
-            else:
-                proportion = as_float(
-                    handle_symptomatic[1],
-                    "Proportion in --handle-symptomatic quarantine_DURATION prop should be a float number",
-                )
-            if proportion > 1 or proportion < 0:
-                raise ValueError(
-                    f'Proportion in "--handle-symptomatic quarantine_DUURATION prop" should be a float number between 0 and 1: {proportion} provided'
-                )
+        elif handle_symptomatic['reaction'] == "quarantine":
+            quarantine_duration = handle_symptomatic.get('duration', 14)
+            proportion = handle_symptomatic.get('proportion', 1)
             if proportion == 1 or np.random.uniform(0, 1, 1)[0] <= proportion:
                 kept = False
                 if symp_time >= 0:
@@ -205,15 +192,15 @@ class Individual(object):
                         Event(
                             symp_time,
                             EventType.QUARANTINE,
-                            target=self.id,
+                            target=self,
                             logger=self.logger,
                             till=symp_time + quarantine_duration,
-                        ))
+                            reason='show symptom'))
                 else:
                     self.quarantined = symp_time + quarantine_duration
-        else:
+        elif handle_symptomatic['reaction'] != 'reintegrate':
             raise ValueError(
-                f'Unrecognizable symptomatic case handling method: {" ".join(handle_symptomatic)}'
+                f'Unrecognizable symptomatic case handling method: {handle_symptomatic}'
             )
 
         # infect only before removal or quarantine
@@ -241,9 +228,9 @@ class Individual(object):
                         Event(
                             time + x,
                             EventType.INFECTION_AVOIDED,
-                            target=self.id,
+                            target=self,
                             logger=self.logger,
-                            by=self.id,
+                            by=self,
                         ))
                     infected[idx] = 0
         #
@@ -255,7 +242,7 @@ class Individual(object):
                         EventType.INFECTION,
                         target=None,
                         logger=self.logger,
-                        by=self.id,
+                        by=self,
                         handle_symptomatic=kwargs.get("handle_symptomatic",
                                                       None),
                     ))
@@ -264,15 +251,12 @@ class Individual(object):
             Event(
                 time + x_grid[-1] - lead_time,
                 EventType.RECOVER,
-                target=self.id,
+                target=self,
                 logger=self.logger,
             ))
-        if by:
-            params = [f"by={by}"]
-        elif lead_time:
-            params = [f"leadtime={lead_time:.2f}"]
-        else:
-            params = []
+        params = [f"by={'.' if by_ind is None else by_ind.id}"]
+        if lead_time:
+            params.append(f"leadtime={lead_time:.2f}")
         #
         params.extend([
             f"r0={self.r0:.2f}",
@@ -294,14 +278,14 @@ class Individual(object):
         else:
             self.r0 = self.model.draw_random_r0(symptomatic=False)
             if self.infectivity is not None:
-                self.r0 *= self.infectivity
+                self.r0 *= self.infectivity[1]
 
         self.r0_multiplier = getattr(
             self.model.params, f"asymptomatic_r0_multiplier_{self.group}", 1.0)
 
         self.incubation_period = -1
 
-        by = kwargs.get("by")
+        by_ind = kwargs.get("by")
         self.infect_params = self.model.draw_infection_params(symptomatic=False)
 
         (x_grid,
@@ -309,7 +293,7 @@ class Individual(object):
              self.r0 * self.r0_multiplier, self.infect_params)
 
         if "leadtime" in kwargs and kwargs["leadtime"] is not None:
-            if by is not None:
+            if by_ind is not None:
                 raise ValueError(
                     "leadtime is only allowed during initialization of infection event (no by option.)"
                 )
@@ -352,9 +336,9 @@ class Individual(object):
                         Event(
                             time + x,
                             EventType.INFECTION_AVOIDED,
-                            target=self.id,
+                            target=self,
                             logger=self.logger,
-                            by=self.id,
+                            by=self,
                         ))
                     infected[idx] = 0
         #
@@ -366,7 +350,7 @@ class Individual(object):
                         EventType.INFECTION,
                         target=None,
                         logger=self.logger,
-                        by=self.id,
+                        by=self,
                         handle_symptomatic=kwargs.get("handle_symptomatic",
                                                       None),
                     ))
@@ -374,14 +358,12 @@ class Individual(object):
             Event(
                 time + x_grid[-1],
                 EventType.RECOVER,
-                target=self.id,
+                target=self,
                 logger=self.logger))
 
-        params = [f"by={'.' if by is None else by}"]
+        params = [f"by={'.' if by_ind is None else by_ind.id}"]
         if lead_time > 0:
-            params = [f"leadtime={lead_time:.2f}"]
-        else:
-            params = []
+            params.append(f"leadtime={lead_time:.2f}")
         #
         params.extend([
             f"r0={self.r0:.2f}",
@@ -418,12 +400,12 @@ class Individual(object):
             raise ValueError('Individual has not been infected yet.')
 
         if self.symptomatic:
-            (x_grid,
+            (_,
              trans_prob) = self.model.get_symptomatic_transmission_probability(
                  self.incubation_period, self.r0 * self.r0_multiplier,
                  self.infect_params)
         else:
-            (x_grid,
+            (_,
              trans_prob) = self.model.get_asymptomatic_transmission_probability(
                  self.r0 * self.r0_multiplier, self.infect_params)
         prob = np.array(trans_prob)
@@ -435,12 +417,12 @@ class Individual(object):
             raise ValueError('Individual has not been infected yet.')
 
         if self.symptomatic:
-            (x_grid,
+            (_,
              trans_prob) = self.model.get_symptomatic_transmission_probability(
                  self.incubation_period, self.r0 * self.r0_multiplier,
                  self.infect_params)
         else:
-            (x_grid,
+            (_,
              trans_prob) = self.model.get_asymptomatic_transmission_probability(
                  self.r0 * self.r0_multiplier, self.infect_params)
         prob = np.array(trans_prob)
@@ -465,7 +447,7 @@ class Individual(object):
                  self.r0, self.infect_params)
         peak_idx = np.argmax(trans_prob)
         idx = int(interval / self.model.params.simulation_interval)
-        multiplier = 0.7 if self.symptomatic else 1.8
+        multiplier = 1  # 0.8 if self.symptomatic else 1.3
         # translate to log10 CP/ML.
         # prob / iterval ==> daily probability from 0.1 up to 0.8
         # 0.01 to 3
@@ -476,9 +458,9 @@ class Individual(object):
         idx = peak_idx + (idx - peak_idx) // 2
         if idx >= len(x_grid):
             return 0
-        else:
-            return (multiplier * trans_prob[idx] /
-                    self.model.params.simulation_interval) * 20
+
+        return (multiplier * trans_prob[idx] /
+                self.model.params.simulation_interval) * 20
 
     def test_sensitivity(self, time, lod):
         # return transmissibility at specified time
@@ -486,30 +468,47 @@ class Individual(object):
         if viral_load == 0.0:
             # if it is 0, it will already be 0
             return 0
-        elif viral_load >= lod:
+
+        if viral_load >= lod:
             return 1
-        else:
-            return viral_load / lod
+
+        return viral_load / lod
 
     def infect(self, time, **kwargs):
-        if isinstance(self.infected, float):
-            by_id = "." if kwargs["by"] is None else kwargs["by"]
+        if isinstance(self.infected,
+                      float) and not isinstance(self.recovered, float):
+            # during infection
+            by_id = "." if kwargs["by"] is None else kwargs["by"].id
             self.logger.write(
                 f"{time:.2f}\t{EventType.INFECTION_IGNORED.name}\t{self.id}\tby={by_id}\n"
             )
             return []
 
         if self.susceptibility < 1 and rand() > self.susceptibility:
-            by_id = "." if kwargs["by"] is None else kwargs["by"]
+            by_id = "." if kwargs["by"] is None else kwargs["by"].id
             self.logger.write(
                 f"{time:.2f}\t{EventType.INFECTION_FAILED.name}\t{self.id}\tby={by_id},reason=susceptibility\n"
             )
             return []
 
         if self.model.draw_is_asymptomatic():
+            if self.immunity is not None and self.immunity[1] > 0 and rand(
+            ) < self.immunity[1]:
+                by_id = "." if kwargs["by"] is None else kwargs["by"].id
+                self.logger.write(
+                    f"{time:.2f}\t{EventType.INFECTION_FAILED.name}\t{self.id}\tby={by_id},reason=immunity\n"
+                )
+                return []
             return self.asymptomatic_infect(time, **kwargs)
-        else:
-            return self.symptomatic_infect(time, **kwargs)
+
+        if self.immunity is not None and self.immunity[0] > 0 and rand(
+        ) < self.immunity[0]:
+            by_id = "." if kwargs["by"] is None else kwargs["by"].id
+            self.logger.write(
+                f"{time:.2f}\t{EventType.INFECTION_FAILED.name}\t{self.id}\tby={by_id},reason=immunity\n"
+            )
+            return []
+        return self.symptomatic_infect(time, **kwargs)
 
 
 class Population(object):
@@ -519,8 +518,8 @@ class Population(object):
         self.group_sizes = {
             (ps.split("=", 1)[0] if "=" in ps else ""): 0 for ps in popsize
         }
-        self.max_ids = {x: y for x, y in self.group_sizes.items()}
-        self.subpop_from_id = re.compile("^(.*?)[\d]+$")
+        self.max_ids = copy.deepcopy(self.group_sizes)
+        self.subpop_from_id = re.compile(r"^(.*?)[\d]+$")
         self.vicinity = self.parse_vicinity(vicinity)
 
         idx = 0
@@ -534,16 +533,17 @@ class Population(object):
                 sz = ps
             try:
                 sz = int(sz)
-            except Exception:
+            except Exception as e:
                 raise ValueError(
-                    f"Named population size should be name=int: {ps} provided")
+                    f"Named population size should be name=int: {ps} provided"
+                ) from e
 
             self.add(
                 [
                     Individual(
                         f"{name}_{idx}" if name else str(idx),
                         susceptibility=getattr(model.params,
-                                               f"susceptibility_mean", 1) *
+                                               "susceptibility_mean", 1) *
                         getattr(model.params,
                                 f"susceptibility_multiplier_{name}", 1),
                         model=model,
@@ -557,13 +557,17 @@ class Population(object):
         if subpop not in self.group_sizes:
             raise ValueError(f'Invalid subpopulation name {subpop}')
         if ID not in self.individuals:
-            return
+            return None
         from_sp = self.individuals[ID].group
+
+        assert from_sp != subpop
+
         self.group_sizes[from_sp] -= 1
         self.group_sizes[subpop] += 1
         new_id = f'{subpop}_{self.max_ids[subpop]}'
         self.individuals[ID].id = new_id
         self.max_ids[subpop] += 1
+        self.individuals[new_id] = self.individuals.pop(ID)
         return new_id
 
     def parse_vicinity(self, params):
@@ -572,13 +576,13 @@ class Population(object):
 
         res = {}
         for param in params:
-            matched = re.match("^(.*)-(.*)=(\d+)$", param)
+            matched = re.match(r"^(.*)-(.*)=(\d+)$", param)
             if matched:
                 infector_sp = matched.group(1)
                 infectee_sp = matched.group(2)
                 neighbor_size = int(matched.group(3))
             else:
-                matched = re.match("^(.*)=(\d+)$", param)
+                matched = re.match(r"^(.*)=(\d+)$", param)
                 if matched:
                     infector_sp = ""
                     infectee_sp = matched.group(1)
@@ -629,13 +633,13 @@ class Population(object):
         sz = len(self.individuals)
         self.individuals.update({x.id: x for x in items})
         if sz + len(items) != len(self.individuals):
-            raise ValueError(f"One or more IDs are already in the population.")
+            raise ValueError("One or more IDs are already in the population.")
         self.group_sizes[subpop] += len(items)
         self.max_ids[subpop] += len(items)
 
-    def replace(self, id, keep=[], **kwargs):
-        old_id = id
-        ind = self.individuals[id]
+    def replace(self, ind, keep=[], **kwargs):
+        assert isinstance(ind, Individual)
+        old_id = ind.id
         grp = ind.group
         idx = self.max_ids[grp]
 
@@ -644,17 +648,11 @@ class Population(object):
         ind.id = f'{grp}_{idx}' if grp else str(idx)
 
         # we keep the susceptibility parameter...
-        for attr, def_value in [
-            ('infected', False),
-            ('infectivity', None),
-            ('show_symptom', False),
-            ('recovered', False),
-            ('symptomatic', None),
-            ('vaccinated', False),
-            ('quarantined', False),
-            ('r0', None),
-            ('incubation_period', None)
-        ]:
+        for attr, def_value in [('infected', False), ('immunity', None),
+                                ('infectivity', None), ('show_symptom', False),
+                                ('recovered', False), ('symptomatic', None),
+                                ('vaccinated', False), ('quarantined', False),
+                                ('r0', None), ('incubation_period', None)]:
             if attr not in keep:
                 setattr(ind, attr, def_value)
 
@@ -665,8 +663,9 @@ class Population(object):
         return self.individuals.keys()
 
     def remove(self, item):
-        self.group_sizes[self.individuals[item].group] -= 1
-        self.individuals.pop(item)
+        assert isinstance(item, Individual)
+        self.group_sizes[item.group] -= 1
+        self.individuals.pop(item.id)
 
     def __len__(self):
         return len(self.individuals)
@@ -677,8 +676,16 @@ class Population(object):
     def __getitem__(self, id):
         return self.individuals[id]
 
-    def items(self):
-        return self.individuals.items()
+    def items(self, group=None):
+        if not group:
+            return self.individuals.items()
+        #
+        if group not in self.group_sizes:
+            raise ValueError(f'Unrecognized subpop {group}')
+
+        prefix = group + '_'
+        return filter(lambda x: x[0].startswith(prefix),
+                      self.individuals.items())
 
     def values(self):
         return self.individuals.values()
@@ -718,16 +725,19 @@ class Population(object):
                     # now, we know the number of qualified invidiauls from each
                     # group, but we still have excluded and quarantined....
             total = sum(freq.values())
+            if total == 0:
+                return None
             freq = {x: y / total for x, y in freq.items()}
             # first determine which group ...
-            grp = choice(groups, 1, p=[freq[x] for x in groups])
+            # note that array(['A']) == 'A' is True
+            grp = choice(groups, 1, p=[freq[x] for x in groups])[0]
 
             # then select a random individual from the group.
             ids = [
-                id for id, ind in self.individuals.items() if
-                ind.group == grp and infector != ind.id and not ind.quarantined
+                id for id, ind in self.items(group=grp)
+                if infector != ind.id and not ind.quarantined
             ]
 
         if not ids:
             return None
-        return choice(ids)
+        return self.individuals[choice(ids)]
