@@ -1,7 +1,6 @@
-from datetime import datetime
 import subprocess
-
 from collections import defaultdict
+from datetime import datetime
 from importlib import import_module
 from itertools import groupby
 
@@ -30,13 +29,13 @@ def load_plugins(args, simulator=None):
             try:
                 mod = import_module(module_name)
             except Exception as e:
-                raise ValueError(f'Failed to import module {module_name}: {e}')
+                raise ValueError(f'Failed to import module {module_name}: {e}') from e
         try:
             obj = getattr(mod, plugin_name)(simulator)
         except Exception as e:
             raise ValueError(
                 f'Failed to retrieve plugin {plugin_name} from module {module_name}: {e}'
-            )
+            ) from e
         # if there is a parser
         parser = obj.get_parser()
         args = parser.parse_args(group[1:])
@@ -97,7 +96,7 @@ class Simulator(object):
                 Event(
                     0,
                     EventType.INFECTION,
-                    target=infector,
+                    target=population[infector],
                     logger=self.logger,
                     by=None,
                     handle_symptomatic=self.simu_args.handle_symptomatic,
@@ -110,9 +109,10 @@ class Simulator(object):
 
         start_params = {
             'id': self.logger.id,
-            'time': datetime.now().strftime("%m/%d/%Y-%H:%M:%S"),
-            'args': subprocess.list2cmdline(self.cmd)
+            'time': datetime.now().strftime("%m/%d/%Y-%H:%M:%S")
         }
+        if self.simu_args.verbosity > 1:
+            start_params['args'] = subprocess.list2cmdline(self.cmd)
         start_params = ','.join([f'{x}={y}' for x, y in start_params.items()])
 
         self.logger.write(
@@ -179,10 +179,10 @@ class Simulator(object):
         infected_by = set()
         for time, events_at_time in events.items():
             for event in events_at_time:
-                if event.action.name in ('SHOW_SYMPTOM', 'RECOVER', 'REMOVAL') and event.target not in population:
+                if event.action.name in ('SHOW_SYMPTOM', 'RECOVER', 'REMOVAL') and event.target.id not in population:
                     continue
-                if event.action.name in ('INFECTION'):
-                    if event.kwargs['by'] in population:
+                if event.action.name == 'INFECTION':
+                    if event.kwargs['by'].id in population:
                         infected_by.add(event.kwargs['by'])
                     else:
                         continue
