@@ -1,25 +1,23 @@
-import os
 import pytest
 from covid19_outbreak_simulator.cli import parse_args, main
-from covid19_outbreak_simulator.model import Params
 
 
-def test_option_base_plugin_help():
+def test_option_base_plugin_help(clear_log):
     args = parse_args(['--plugin', '-h'])
     assert args.plugin == ['-h']
 
 
-def test_option_plugin_help():
+def test_option_plugin_help(clear_log):
     args = parse_args(['--plugin', 'sample', '-h'])
     assert args.plugin == ['sample', '-h']
 
 
-def test_option_plugin_args():
+def test_option_plugin_args(clear_log):
     args = parse_args(['--plugin', 'sample', '--sample-size', '100'])
     assert args.plugin == ['sample', '--sample-size', '100']
 
 
-def test_plugin_no_module():
+def test_plugin_no_module(clear_log):
     with pytest.raises(Exception):
         main([
             '--jobs', '1', '--repeats', '100', '--infectors', '1', '--plugin',
@@ -27,7 +25,7 @@ def test_plugin_no_module():
         ])
 
 
-def test_plugin_no_module():
+def test_plugin_no_module_1(clear_log):
     with pytest.raises(Exception):
         main([
             '--jobs', '1', '--repeats', '100', '--infectors', '1', '--plugin',
@@ -35,7 +33,7 @@ def test_plugin_no_module():
         ])
 
 
-def test_plugin_trigger():
+def test_plugin_trigger(clear_log):
     main([
         '--jobs', '1', '--repeats', '100', '--infectors', '1', '--plugin',
         'stat', '--trigger-by', 'INFECTION'
@@ -74,6 +72,18 @@ def test_plugin_quarantine(clear_log):
         '--proportion', 'A=1', 'B=0', '--target', 'infected'
     ])
 
+    main([
+        '--jobs', '1', '--popsize', 'A=100', 'B=200', '--infector', 'A_10',
+        '--repeats', '100', '--plugin', 'quarantine', '--duration', '7',
+        '--proportion', 'A=1', 'B=0', '--target', 'uninfected'
+    ])
+
+    main([
+        '--jobs', '1', '--popsize', 'A=100', 'B=200', '--infector', 'A_10',
+        '--repeats', '100', '--plugin', 'quarantine', '--duration', '7',
+        '--count', 'A=10', 'B=20', '--target', 'uninfected'
+    ])
+
 
 def test_plugin_quarantine_error(clear_log):
     with pytest.raises((Exception, SystemExit)):
@@ -95,20 +105,20 @@ def test_plugin_quarantine_error(clear_log):
         ])
 
 
-def test_plugin_stat():
+def test_plugin_stat(clear_log):
     main([
         '--jobs', '1', '--repeats', '100', '--plugin', 'stat', '--interval', '1'
     ])
 
 
-def test_plugin_stat_with_groups():
+def test_plugin_stat_with_groups(clear_log):
     main([
         '--jobs', '1', '--popsize', 'A=200', 'B=100', '--repeats', '100',
         '--infectors', 'A_0', '--plugin', 'stat', '--interval', '1'
     ])
 
 
-def test_plugin_init():
+def test_plugin_init(clear_log):
     main([
         '--jobs', '1', '--repeats', '100', '--plugin', 'init', '--at', '0',
         '--incidence-rate', '0.01'
@@ -126,7 +136,7 @@ def test_plugin_init():
     ])
 
 
-def test_plugin_sample():
+def test_plugin_sample(clear_log):
     main([
         '--jobs', '1', '--repeats', '100', '--plugin', 'sample', '--interval',
         '1', '--proportion', '0.8'
@@ -137,7 +147,7 @@ def test_plugin_sample():
     ])
 
 
-def test_plugin_sample_error():
+def test_plugin_sample_error(clear_log):
     with pytest.raises((Exception, SystemExit)):
         main([
             '--jobs', '1', '--repeats', '100', '--plugin', 'sample',
@@ -157,7 +167,7 @@ def test_plugin_sample_error():
         ])
 
 
-def test_plugin_setparam():
+def test_plugin_setparam(clear_log):
     main([
         '--jobs', '1', '--repeats', '100', '--plugin', 'setparam', '--at', '1',
         '--symptomatic-r0', '0.2'
@@ -168,7 +178,7 @@ def test_plugin_setparam():
     ])
 
 
-def test_plugin_insert():
+def test_plugin_insert(clear_log):
     main([
         '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--plugin',
         'insert', '2', '--at', '1'
@@ -179,7 +189,7 @@ def test_plugin_insert():
     ])
 
 
-def test_plugin_remove():
+def test_plugin_remove(clear_log):
     main([
         '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--plugin',
         'remove', '2', '--at', '1'
@@ -190,7 +200,7 @@ def test_plugin_remove():
     ])
 
 
-def test_plugin_community_infection():
+def test_plugin_community_infection(clear_log):
     main([
         '--jobs', '1', '--repeats', '10', '--stop-if', 't>4', '--plugin',
         'community_infection', '--probability', '0.0001', '--interval', '1'
@@ -202,7 +212,7 @@ def test_plugin_community_infection():
     ])
 
 
-def test_plugin_insert_hetero_pop():
+def test_plugin_insert_hetero_pop(clear_log):
     main([
         '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--popsize',
         'A=100', 'B=100', '--stop-if', 't>10', '--plugin', 'insert', 'A=2',
@@ -210,15 +220,15 @@ def test_plugin_insert_hetero_pop():
     ])
 
 
-def test_plugin_testing():
+def test_plugin_testing(clear_log):
     main(['--jobs', '1', '--repeats', '100', '--plugin', 'testing'])
 
     main(['--jobs', '1', '--repeats', '100', '--plugin', 'testing', '1', '2'])
 
     main([
         '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200',
-        '--infector', 'A_2', 'A_7', '--plugin', 'testing', 'A_2', 'A_7',
-        '--handle-positive', 'quarantine_7'
+        '--infector', 'A_2', 'A_7', '--handle-symptomatic', 'keep', '--plugin', 'testing', 'A_2', 'A_7',
+        '--at', '3', '--handle-positive', 'quarantine@duration=14'
     ])
 
     main([
@@ -226,8 +236,13 @@ def test_plugin_testing():
         '--turnaround-time', '2'
     ])
 
+    main([
+        '--jobs', '1', '--repeats', '100', '--plugin', 'testing', '1', '2',
+        '--turnaround-time', '2', '--target', 'infected'
+    ])
 
-def test_plugin_vaccinate():
+
+def test_plugin_vaccinate(clear_log):
     main(['--jobs', '1', '--repeats', '100', '--plugin', 'vaccinate'])
 
     main(['--jobs', '1', '--repeats', '100', '--plugin', 'vaccinate', '1', '2'])
